@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -77,6 +77,14 @@ public class ServiceDependentRegistration<T> extends ConditionalRegistration imp
         this(context, serviceName, service, null, whiteboard);
     }
     
+    public ServiceDependentRegistration(BundleContext context, String serviceName, Whiteboard whiteboard) {
+        this(context, serviceName, (T) null, whiteboard);
+    }
+    
+    public ServiceDependentRegistration(BundleContext context, String serviceName, Dictionary dict, Whiteboard whiteboard) {
+        this(context, serviceName, null, dict, whiteboard);
+    }
+    
     /**
      * Override to configure the service
      * @param service
