@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2006 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2010 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -158,4 +158,8 @@ public interface Session {
      */
     public void removeRandomToken();
 
+    /**
+     * @return the authentication identifier that is used to trace the login request across different systems.
+     */
+    String getAuthId();
 }
